"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Provider = void 0;
const tslib_1 = require("tslib");
const api_gateway_io_1 = require("./library/api-gateway-io");
/**
 * `Provider` is a function that accepts a list of rocket names and returns an
 * object compatible with the `ProviderLibrary` defined in the `framework-types` package.
 * The rocket names are passed to the infrastructure package, which loads them dynamically
 * to extend the AWS functionality. Rockets are typically distributed in separate node packages.
 */
const Provider = (rockets) => {
    try {
        require('aws-sdk');
        const { Provider } = require('./setup');
        return Provider(rockets);
    }
    catch (e) {
        return {
            // ProviderEventsLibrary
            events: {
                rawToEnvelopes: undefined,
                forEntitySince: undefined,
                latestEntitySnapshot: undefined,
                store: undefined,
                search: undefined,
                searchEntitiesIDs: undefined,
            },
            // ProviderReadModelsLibrary
            readModels: {
                rawToEnvelopes: undefined,
                fetch: undefined,
                search: undefined,
                store: undefined,
                delete: undefined,
                subscribe: undefined,
                fetchSubscriptions: undefined,
                deleteSubscription: undefined,
                deleteAllSubscriptions: undefined,
            },
            // ProviderGraphQLLibrary
            graphQL: {
                rawToEnvelope: undefined,
                handleResult: undefined,
            },
            // ProviderAPIHandling
            api: {
                requestSucceeded: api_gateway_io_1.requestSucceeded,
                requestFailed: api_gateway_io_1.requestFailed,
            },
            connections: {
                storeData: undefined,
                fetchData: undefined,
                deleteData: undefined,
                sendMessage: undefined,
            },
            // ScheduledCommandsLibrary
            scheduled: {
                rawToEnvelope: undefined,
            },
            // ProviderInfrastructureGetter
            infrastructure: () => require(require('../package.json').name + '-infrastructure').Infrastructure,
        };
    }
};
exports.Provider = Provider;
tslib_1.__exportStar(require("./constants"), exports);
